@@ -1,4 +1,4 @@
-/* $OpenBSD: enc.c,v 1.6 2015/09/10 16:01:06 jsing Exp $ */
+/* $OpenBSD: enc.c,v 1.9 2015/10/17 07:51:10 semarie Exp $ */
 /* Copyright (C) 1995-1998 Eric Young (eay@cryptsoft.com)
  * All rights reserved.
  *
@@ -338,6 +338,13 @@ enc_main(int argc, char **argv)
 	char pname[PROG_NAME_SIZE + 1];
 	int i;
 
+	if (single_execution) {
+		if (pledge("stdio rpath wpath cpath tty", NULL) == -1) {
+			perror("pledge");
+			exit(1);
+		}
+	}
+
 	memset(&enc_config, 0, sizeof(enc_config));
 	enc_config.enc = 1;
 
