@@ -1,4 +1,4 @@
-/* $OpenBSD: req.c,v 1.8 2015/09/13 23:36:21 doug Exp $ */
+/* $OpenBSD: req.c,v 1.11 2015/10/17 07:51:10 semarie Exp $ */
 /* Copyright (C) 1995-1998 Eric Young (eay@cryptsoft.com)
  * All rights reserved.
  *
@@ -176,6 +176,13 @@ req_main(int argc, char **argv)
 	const EVP_MD *md_alg = NULL, *digest = NULL;
 	unsigned long chtype = MBSTRING_ASC;
 
+	if (single_execution) {
+		if (pledge("stdio rpath wpath cpath tty", NULL) == -1) {
+			perror("pledge");
+			exit(1);
+		}
+	}
+
 	req_conf = NULL;
 	cipher = EVP_aes_256_cbc();
 	digest = EVP_sha256();
